VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package dam

Package {dam}


Title: Data Analysis Metabolomics
Version: 0.0.1
Description: A collection of functions which aim to assist common computational workflow for analysis of matabolomic data..
Depends: R (≥ 3.2.3)
License: CC0
Encoding: UTF-8
LazyData: true
RoxygenNote: 5.0.1.9000
NeedsCompilation: no
Packaged: 2016-06-09 12:36:30 UTC; slakov
Author: Slavik Koval [aut, cre]
Maintainer: Slavik Koval <slakov@gmail.com>
Repository: CRAN
Date/Publication: 2016-06-09 15:19:21

A correctedMarkers Function

Description

This function allows you to perform several multiple regression on metabolomic data.

Usage

correctedMarkers(dat, fac, con, comp)

Arguments

dat

Data matrix.

fac

Index of the group of samples.

con

Index of correction variable.

comp

Index (range) of measured compounds.

Examples

correctedMarkers(iris, 5, 1, 2:4)

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.