| Title: | Data Analysis Metabolomics |
|---|---|
| Description: | A collection of functions which aim to assist common computational workflow for analysis of matabolomic data.. |
| Authors: | Slavik Koval [aut, cre] |
| Maintainer: | Slavik Koval <[email protected]> |
| License: | CC0 |
| Version: | 0.0.1 |
| Built: | 2026-05-20 10:35:57 UTC |
| Source: | https://github.com/cran/dam |
This function allows you to perform several multiple regression on metabolomic data.
correctedMarkers(dat, fac, con, comp)correctedMarkers(dat, fac, con, comp)
dat |
Data matrix. |
fac |
Index of the group of samples. |
con |
Index of correction variable. |
comp |
Index (range) of measured compounds. |
correctedMarkers(iris, 5, 1, 2:4)correctedMarkers(iris, 5, 1, 2:4)